pymediainfo
-----------

.. image:: https://img.shields.io/pypi/v/pymediainfo.svg
  :target: https://pypi.org/project/pymediainfo

.. image:: https://img.shields.io/pypi/pyversions/pymediainfo.svg
  :target: https://pypi.org/project/pymediainfo

.. image:: https://repology.org/badge/tiny-repos/python:pymediainfo.svg
  :target: https://repology.org/metapackage/python:pymediainfo

.. image:: https://img.shields.io/pypi/implementation/pymediainfo.svg
  :target: https://pypi.org/project/pymediainfo

.. image:: https://ci.appveyor.com/api/projects/status/g15a2daem1oub57n/branch/master?svg=true
  :target: https://ci.appveyor.com/project/sbraz/pymediainfo


This small package is a wrapper around the MediaInfo library.

It works on Linux, Mac OS X and Windows and is tested with Python 3.7 to 3.11 and PyPy3.

See https://pymediainfo.readthedocs.io/ for more information.
